.. currentmodule:: sardana.pool.poolpseudomotor

:mod:`~sardana.pool.poolpseudomotor`
======================================

.. automodule:: sardana.pool.poolpseudomotor

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`PoolPseudoMotor`


PoolPseudoMotor
----------------

.. inheritance-diagram:: PoolPseudoMotor
    :parts: 1
    
.. autoclass:: PoolPseudoMotor
    :show-inheritance:
    :members:
    :undoc-members:

